"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || (function () {
    var ownKeys = function(o) {
        ownKeys = Object.getOwnPropertyNames || function (o) {
            var ar = [];
            for (var k in o) if (Object.prototype.hasOwnProperty.call(o, k)) ar[ar.length] = k;
            return ar;
        };
        return ownKeys(o);
    };
    return function (mod) {
        if (mod && mod.__esModule) return mod;
        var result = {};
        if (mod != null) for (var k = ownKeys(mod), i = 0; i < k.length; i++) if (k[i] !== "default") __createBinding(result, mod, k[i]);
        __setModuleDefault(result, mod);
        return result;
    };
})();
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.codegenerate = codegenerate;
const promises_1 = require("node:fs/promises");
const node_path_1 = require("node:path");
const axios_1 = __importDefault(require("axios"));
const yaml = __importStar(require("yaml"));
const clientGenerator_1 = require("./generator/clientGenerator");
const instanceGenerator_1 = require("./generator/instanceGenerator");
const reactQueryGenerator_1 = require("./generator/reactQueryGenerator");
const schemaGenerator_1 = require("./generator/schemaGenerator");
const utils_1 = require("./utils");
/**
 * Loads the OpenAPI specification from either a URL or local file
 */
async function loadOpenAPISpec(specSource) {
    try {
        if (specSource.startsWith("http")) {
            const response = await axios_1.default.get(specSource);
            // Check if response is YAML by looking for common YAML indicators
            const isYaml = typeof response.data === "string" &&
                (response.data.trim().startsWith("openapi:") || response.data.trim().startsWith("swagger:"));
            return isYaml ? yaml.parse(response.data) : response.data;
        }
        const content = await (0, promises_1.readFile)(specSource, "utf-8");
        // Handle both JSON and YAML formats
        return specSource.endsWith(".json") ? JSON.parse(content) : yaml.parse(content);
    }
    catch (error) {
        if (error instanceof Error) {
            throw new Error(`Failed to load OpenAPI spec: ${error.message}`);
        }
        throw new Error("Failed to load OpenAPI spec: Unknown error");
    }
}
/**
 * Main function to generate the API client
 */
async function codegenerate(config) {
    try {
        // Load specs
        const specs = Array.isArray(config.specSource)
            ? await Promise.all(config.specSource.map(loadOpenAPISpec))
            : [await loadOpenAPISpec(config.specSource)];
        // Create export directory if it doesn't exist
        await (0, promises_1.mkdir)(config.exportDir, { recursive: true });
        // Generate and write type definitions
        const instance = (0, instanceGenerator_1.generateInstance)();
        await (0, promises_1.writeFile)((0, node_path_1.resolve)(config.exportDir, "apiClient.ts"), instance, "utf-8");
        // Generate for each spec...
        for (const spec of specs) {
            const title = (0, utils_1.specTitle)(spec);
            // Generate and write type definitions
            const typeDefinitions = (0, schemaGenerator_1.generateTypeDefinitions)(spec);
            await (0, promises_1.writeFile)((0, node_path_1.resolve)(config.exportDir, `${title}.schema.ts`), typeDefinitions, "utf-8");
            // Generate and write API client
            const clientCode = (0, clientGenerator_1.generateApiClient)(spec, config);
            await (0, promises_1.writeFile)((0, node_path_1.resolve)(config.exportDir, `${title}.client.ts`), clientCode, "utf-8");
            // Generate and write React Query options
            const queryCode = (0, reactQueryGenerator_1.generateReactQuery)(spec);
            await (0, promises_1.writeFile)((0, node_path_1.resolve)(config.exportDir, `${title}.queryOptions.ts`), queryCode, "utf-8");
        }
    }
    catch (error) {
        if (error instanceof Error) {
            throw new Error(`Failed to generate API client: ${error.message}`);
        }
        throw new Error("Failed to generate API client: Unknown error");
    }
}
